@@ -16,3 +16,14 @@ class Link(Resource):
         return six.text_type('<Link: method={method}, rel={rel}, href={href}>'
                              .format(method=self.method, rel=self.rel,
                                      href=self.href))
+
+
+class VolumeLink(Resource):
+    """
+    Pagination links for volumes.
+    """
+    next = HrefField()
+
+    def __str__(self):
+        return six.text_type(
+            '<VolumeLink: next={next}>'.format(next=self.next))
