@@ -14,7 +14,7 @@ from sevenbridges.models.compound.volumes.service import VolumeService
 from sevenbridges.models.compound.volumes.volume_object import VolumeObject
 from sevenbridges.models.compound.volumes.volume_prefix import VolumePrefix
 from sevenbridges.models.enums import VolumeType
-from sevenbridges.models.link import Link
+from sevenbridges.models.link import Link, VolumeLink
 from sevenbridges.models.member import Member
 
 logger = logging.getLogger(__name__)
@@ -31,8 +31,8 @@ class Volume(Resource):
         'delete': '/storage/volumes/{id}',
         'list': '/storage/volumes/{id}/list',
         'object': '/storage/volumes/{id}/object',
+        'member': '/storage/volumes/{id}/members/{username}',
         'members_query': '/storage/volumes/{id}/members',
-        'members_get': '/storage/volumes/{id}/members/{member}',
     }
 
     href = HrefField()
@@ -46,13 +46,14 @@ class Volume(Resource):
     active = BooleanField(read_only=True)
 
     def __eq__(self, other):
-        if self is None and other:
+        if not hasattr(other, '__class__'):
             return False
-        if other is None and self:
+        if not self.__class__ == other.__class__:
             return False
-        if self is other:
-            return True
-        return self.id == other.id and self.__class__ == other.__class__
+        return self is other or self.id == other.id
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
 
     def __str__(self):
         return six.text_type('<Volume: id={id}>'.format(id=self.id))
@@ -162,6 +163,54 @@ class Volume(Resource):
         response = api.post(url=cls._URL['query'], data=data).json()
         return Volume(api=api, **response)
 
+    @classmethod
+    def create_oss_volume(cls, name, bucket, endpoint, access_key_id,
+                          secret_access_key, access_mode, description=None,
+                          prefix=None, properties=None, api=None):
+        """
+        Create oss volume.
+        :param name: Volume name.
+        :param bucket: Referenced bucket.
+        :param access_key_id: Access key identifier.
+        :param secret_access_key: Secret access key.
+        :param access_mode: Access Mode.
+        :param endpoint: Volume Endpoint.
+        :param description: Volume description.
+        :param prefix: Volume prefix.
+        :param properties: Volume properties.
+        :param api: Api instance.
+        :return: Volume object.
+        """
+        service = {
+            'type': VolumeType.OSS,
+            'bucket': bucket,
+            'endpoint': endpoint,
+            'credentials': {
+                'access_key_id': access_key_id,
+                'secret_access_key': secret_access_key
+            }
+        }
+        if prefix:
+            service['prefix'] = prefix
+        if properties:
+            service['properties'] = properties
+
+        data = {
+            'name': name,
+            'service': service,
+            'access_mode': access_mode
+        }
+        if description:
+            data['description'] = description
+        api = api or cls._API
+        extra = {
+            'resource': cls.__name__,
+            'query': data
+        }
+        logger.info('Creating oss volume', extra=extra)
+        response = api.post(url=cls._URL['query'], data=data).json()
+        return Volume(api=api, **response)
+
     @inplace_reload
     def save(self, inplace=True):
         """
@@ -196,7 +245,7 @@ class Volume(Resource):
             url=self._URL['list'].format(id=self.id), params=params).json()
 
         href = data['href']
-        links = [Link(**link) for link in data['links']]
+        links = [VolumeLink(**link) for link in data['links']]
 
         objects = [
             VolumeObject(api=self._api, **item) for item in data['items']
@@ -277,7 +326,7 @@ class Volume(Resource):
         :return: Member object.
         """
         user = Transform.to_user(user)
-        data = {'id': user, 'type': 'USER'}
+        data = {'username': user, 'type': 'USER'}
 
         if 'execute' in permissions:
             permissions.pop('execute')
@@ -294,7 +343,7 @@ class Volume(Resource):
                 'data': data,
             }
         }
-        logger.info('Adding volume member using username', extra=extra)
+        logger.info('Adding volume member', extra=extra)
         response = self._api.post(
             url=self._URL['members_query'].format(id=self.id), data=data)
         member_data = response.json()
@@ -308,7 +357,7 @@ class Volume(Resource):
         :return: Member object.
         """
         team = Transform.to_team(team)
-        data = {'id': team, 'type': 'TEAM'}
+        data = {'username': team, 'type': 'TEAM'}
 
         if 'execute' in permissions:
             permissions.pop('execute')
@@ -325,7 +374,7 @@ class Volume(Resource):
                 'data': data,
             }
         }
-        logger.info('Adding volume team member using team id', extra=extra)
+        logger.info('Adding volume team member', extra=extra)
         response = self._api.post(
             url=self._URL['members_query'].format(id=self.id), data=data)
         member_data = response.json()
@@ -343,7 +392,7 @@ class Volume(Resource):
         if 'execute' in permissions:
             permissions.pop('execute')
 
-        data = {'id': division, 'type': 'DIVISION'}
+        data = {'username': division, 'type': 'DIVISION'}
         if isinstance(permissions, dict):
             data.update({
                 'permissions': permissions
@@ -356,18 +405,33 @@ class Volume(Resource):
                 'data': data,
             }
         }
-        logger.info('Adding volume team member using division id', extra=extra)
+        logger.info('Adding volume division member', extra=extra)
         response = self._api.post(
             url=self._URL['members_query'].format(id=self.id), data=data)
         member_data = response.json()
         return Member(api=self._api, **member_data)
 
+    def get_member(self, username, api=None):
+        """
+        Fetches information about a single volume member
+        :param username: Member name
+        :param api: Api instance
+        :return: Member object
+        """
+        api = api if api else self._API
+
+        response = api.get(
+            url=self._URL['member'].format(id=self.id, username=username),
+        )
+        data = response.json()
+        return Member(api=api, **data)
+
     def remove_member(self, user):
         """
         Remove member from the volume.
         :param user: User to be removed.
         """
-        member = Transform.to_user(user)
+        username = Transform.to_user(user)
         extra = {
             'resource': self.__class__.__name__,
             'query': {
@@ -377,5 +441,5 @@ class Volume(Resource):
         }
         logger.info('Removing volume member', extra=extra)
         self._api.delete(
-            url=self._URL['members_get'].format(id=self.id, member=member)
+            url=self._URL['member'].format(id=self.id, username=username)
         )
